==> aws-java-sdk-api-gateway-1.10.59-sources.jar: com/amazonaws/services/apigateway/model/transform/GetResourcesRequestMarshaller.java <==
/*
 * Copyright 2010-2016 Amazon.com, Inc. or its affiliates. All Rights
 * Reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License").
 * You may not use this file except in compliance with the License.
 * A copy of the License is located at
 *
 *  http://aws.amazon.com/apache2.0
 *
 * or in the "license" file accompanying this file. This file is distributed
 * on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either
 * express or implied. See the License for the specific language governing
 * permissions and limitations under the License.
 */

package com.amazonaws.services.apigateway.model.transform;

import static com.amazonaws.util.StringUtils.UTF8;
import static com.amazonaws.util.StringUtils.COMMA_SEPARATOR;
import java.io.ByteArrayInputStream;
import java.io.ByteArrayOutputStream;
import java.io.OutputStreamWriter;
import java.io.StringWriter;
import java.io.Writer;
import java.util.Collections;
import java.util.HashMap;
import java.util.Map;
import java.util.List;
import java.util.regex.Pattern;

import com.amazonaws.AmazonClientException;
import com.amazonaws.Request;
import com.amazonaws.DefaultRequest;
import com.amazonaws.http.HttpMethodName;
import com.amazonaws.services.apigateway.model.*;
import com.amazonaws.transform.Marshaller;
import com.amazonaws.util.BinaryUtils;
import com.amazonaws.util.StringUtils;
import com.amazonaws.util.StringInputStream;
import com.amazonaws.util.json.*;

/**
 * GetResourcesRequest Marshaller
 */
public class GetResourcesRequestMarshaller implements
        Marshaller<Request<GetResourcesRequest>, GetResourcesRequest> {

    private static final String DEFAULT_CONTENT_TYPE = "";

    public Request<GetResourcesRequest> marshall(
            GetResourcesRequest getResourcesRequest) {

        if (getResourcesRequest == null) {
            throw new AmazonClientException(
                    "Invalid argument passed to marshall(...)");
        }

        Request<GetResourcesRequest> request = new DefaultRequest<GetResourcesRequest>(
                getResourcesRequest, "AmazonApiGateway");

        request.setHttpMethod(HttpMethodName.GET);

        String uriResourcePath = "/restapis/{restapi_id}/resources";

        uriResourcePath = uriResourcePath.replace(
                "{restapi_id}",
                (getResourcesRequest.getRestApiId() == null) ? "" : StringUtils
                        .fromString(getResourcesRequest.getRestApiId()));
        request.setResourcePath(uriResourcePath);

        String position = (getResourcesRequest.getPosition() == null) ? null
                : StringUtils.fromString(getResourcesRequest.getPosition());
        if (position != null) {
            request.addParameter("position", position);
        }

        String limit = (getResourcesRequest.getLimit() == null) ? null
                : StringUtils.fromInteger(getResourcesRequest.getLimit());
        if (limit != null) {
            request.addParameter("limit", limit);
        }

        request.setContent(new ByteArrayInputStream(new byte[0]));
        if (!request.getHeaders().containsKey("Content-Type")) {
            request.addHeader("Content-Type", DEFAULT_CONTENT_TYPE);
        }

        return request;
    }

}

==> aws-java-sdk-api-gateway-1.10.75.1-sources.jar: com/amazonaws/services/apigateway/model/transform/GetResourcesRequestMarshaller.java <==
/*
 * Copyright 2010-2016 Amazon.com, Inc. or its affiliates. All Rights
 * Reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License").
 * You may not use this file except in compliance with the License.
 * A copy of the License is located at
 *
 *  http://aws.amazon.com/apache2.0
 *
 * or in the "license" file accompanying this file. This file is distributed
 * on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either
 * express or implied. See the License for the specific language governing
 * permissions and limitations under the License.
 */

package com.amazonaws.services.apigateway.model.transform;

import static com.amazonaws.util.StringUtils.UTF8;
import static com.amazonaws.util.StringUtils.COMMA_SEPARATOR;
import java.io.ByteArrayInputStream;
import java.io.ByteArrayOutputStream;
import java.io.OutputStreamWriter;
import java.io.StringWriter;
import java.io.Writer;
import java.util.Collections;
import java.util.HashMap;
import java.util.Map;
import java.util.List;
import java.util.regex.Pattern;

import com.amazonaws.AmazonClientException;
import com.amazonaws.Request;
import com.amazonaws.DefaultRequest;
import com.amazonaws.http.HttpMethodName;
import com.amazonaws.services.apigateway.model.*;
import com.amazonaws.transform.Marshaller;
import com.amazonaws.util.BinaryUtils;
import com.amazonaws.util.StringUtils;
import com.amazonaws.util.IdempotentUtils;
import com.amazonaws.util.StringInputStream;
import com.amazonaws.util.json.*;

/**
 * GetResourcesRequest Marshaller
 */
public class GetResourcesRequestMarshaller implements
        Marshaller<Request<GetResourcesRequest>, GetResourcesRequest> {

    private static final String DEFAULT_CONTENT_TYPE = "";

    public Request<GetResourcesRequest> marshall(
            GetResourcesRequest getResourcesRequest) {

        if (getResourcesRequest == null) {
            throw new AmazonClientException(
                    "Invalid argument passed to marshall(...)");
        }

        Request<GetResourcesRequest> request = new DefaultRequest<GetResourcesRequest>(
                getResourcesRequest, "AmazonApiGateway");

        request.setHttpMethod(HttpMethodName.GET);

        String uriResourcePath = "/restapis/{restapi_id}/resources";

        uriResourcePath = uriResourcePath.replace(
                "{restapi_id}",
                (getResourcesRequest.getRestApiId() != null) ? StringUtils
                        .fromString(getResourcesRequest.getRestApiId()) : "");
        request.setResourcePath(uriResourcePath);

        if (getResourcesRequest.getPosition() != null) {
            request.addParameter("position",
                    StringUtils.fromString(getResourcesRequest.getPosition()));
        }

        if (getResourcesRequest.getLimit() != null) {
            request.addParameter("limit",
                    StringUtils.fromInteger(getResourcesRequest.getLimit()));
        }

        request.setContent(new ByteArrayInputStream(new byte[0]));
        if (!request.getHeaders().containsKey("Content-Type")) {
            request.addHeader("Content-Type", DEFAULT_CONTENT_TYPE);
        }

        return request;
    }

}
